@@ -10,9 +10,9 @@ See the cf-plot home page http://ajheaps.github.io/cf-plot for a gallery of plot
 '''
 
 __author__ = 'Andy Heaps - andy.heaps@ncas.ac.uk'
-__date__ = '7th March 2019'
-__version__ = '2.3.2'
+__date__ = '27th Apil 2020
+__version__ = '3.0.17'
 
-from cfplot import *
+from .cfplot import *
 
 
